<?php
/**
* Xapian PHP5 Wrapper Smoke Test
* 
* Adaptation of Olly Bett's original PHP smoke test for the raw Xapian APIs
*
* Copyright  2006 Paul Dixon (paul@elphin.com)
* blog : http://blog.dixo.net
* email: (paul@elphin.com
* 
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

require_once("xapian_php5.php");


if (!extension_loaded('xapian'))
	dl("xapian.so");

$stem = new XapianStem("english");
if ($stem->get_description() != "Xapian::Stem(english)") die("stem->get_description failed");
$doc = new XapianDocument();
$doc->set_data("is there anybody out there?");
$doc->add_term("XYzzy");
$doc->add_posting($stem->stem_word("is"), 1);
$doc->add_posting($stem->stem_word("there"), 2);
$doc->add_posting($stem->stem_word("anybody"), 3);
$doc->add_posting($stem->stem_word("out"), 4);
$doc->add_posting($stem->stem_word("there"), 5);
$db = new XapianWritableDatabase(inmemory_open());

// Check virtual function dispatch - this is really a test of the PHP function
// internals, but we can do it with the classes...

//first we wrap the writable database in a normal Database class - we can't pass
//the ptr in as a constructor as XapianDatabase expects a Database resource, so
//we have hack it... (note that a XapianWritableDatabase inherits member functions
//from XapianDatabase, we just don't have a way to create a XapianDatabase from a
//XapianWritableDatabase - but you'd never need to do this in practice)
$db2=new XapianDatabase();
$db2->ptr=$db->ptr;

if ($db->get_description() != $db2->get_description())
    die("virtual function dispatch failed");
    
$db->add_document($doc);
if ($db->get_doccount() != 1) die("db->get_doccount() failed");
$terms = array("smoke", "test", "terms");



$query = new XapianQuery(Query_OP_OR, $terms);
if ($query->get_description() != "Xapian::Query((smoke OR test OR terms))") die("Query_OP_OR failed");

$query1 = new XapianQuery(Query_OP_PHRASE, array("smoke", "test", "tuple"));
if ($query1->get_description() != "Xapian::Query((smoke PHRASE 3 test PHRASE 3 tuple))") die("Query_OP_PHRASE failed - got ".$query->get_description());

$query2 = new XapianQuery(Query_OP_XOR, array(new XapianQuery("smoke"), $query1, "string"));
if ($query2->get_description() != "Xapian::Query((smoke XOR (smoke PHRASE 3 test PHRASE 3 tuple) XOR string))") die("Query_OP_XOR failed");
$subqs = array("a", "b");


$query3 = new XapianQuery(Query_OP_OR, $subqs);
if ($query3->get_description() != "Xapian::Query((a OR b))") die("Query_OP_OR failed (2)");

$enq = new XapianEnquire($db);
$enq->set_query(new XapianQuery(Query_OP_OR, "there", "is"));
$mset = $enq->get_mset(0, 10);
if ($mset->size() != 1) die("mset->size() failed");
$terms = join(" ", $enq->get_matching_terms($mset->get_hit(0)));
if ($terms != "is there") die("enq->get_matching_terms failed");

# Check PHP4 handling of Xapian::DocNotFoundError
$old_error_reporting = error_reporting();
if ($old_error_reporting & E_WARNING)
    error_reporting($old_error_reporting ^ E_WARNING);
$doc2 = $db->get_document(2);
if ($doc2 != null) {
    die("$db->get_document(2) failed");
}
if ($old_error_reporting & E_WARNING)
    error_reporting($old_error_reporting);


echo "Smoke test succeeded!\n";
?>